<?php
namespace Opencart\Admin\Controller\Extension\Vtbpay\Payment;

class VtbPay extends \Opencart\System\Engine\Controller 
{
	
		/**
		 * Index function
		 *
		 * This method handles the loading of the VTB Pay extension page in the OpenCart admin.
		 * It sets up the necessary data for the view, including breadcrumbs, save and back URLs,
		 * and VTB Pay specific configuration values.
		 *
		 * @return void
		 */
		public function index(): void 
		{
				$this->load->language('extension/vtbpay/payment/vtbpay');
				$this->document->setTitle($this->language->get('heading_title'));
				$this->load->model('localisation/order_status');

				$fields = [
						'desc',
				    'client_id', 
				    'client_secret', 
				    'merchant_authorization', 
				    'transaction_end_status', 
				    'test_mode', 
				    'logging',
						'status',
						'sort_order'
			  ];
			  
				foreach ($fields as $field) {
						$data['payment_vtbpay_' . $field] = $this->config->get('payment_vtbpay_' . $field);
				}
				
				if(empty($data['payment_vtbpay_desc']))
				{
						$data['payment_vtbpay_desc'] = $this->language->get('default_value_desc');
				}

				$data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();


				$this->showPaymentSettingsPage($data);
		}


		/**
		 * showPaymentSettingsPage method
		 *
		 * This method prepares the breadcrumbs and other necessary data for the view,
		 * and then it renders the payment settings page.
		 *
		 * @param array $data The data array that will be passed to the view.
		 * @return void
		 */
		private function showPaymentSettingsPage(array $data): void 
		{
				$data['breadcrumbs'] = [];

				$data['breadcrumbs'][] = [
						'text' => $this->language->get('text_home'),
						'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'])
				];

				$data['breadcrumbs'][] = [
						'text' => $this->language->get('text_extension'),
						'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment')
				];

				$data['breadcrumbs'][] = [
						'text' => $this->language->get('heading_title'),
						'href' => $this->url->link('extension/vtbpay/payment/vtbpay', 'user_token=' . $this->session->data['user_token'])
				];

				$data['save'] = $this->url->link('extension/vtbpay/payment/vtbpay.save', 'user_token=' . $this->session->data['user_token']);
				$data['back'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment');

				$data['header'] = $this->load->controller('common/header');
				$data['column_left'] = $this->load->controller('common/column_left');
				$data['footer'] = $this->load->controller('common/footer');

				$this->response->setOutput($this->load->view('extension/vtbpay/payment/vtbpay', $data));
		}


		/**
		 * Save function
		 *
		 * This method handles the submission of the VTB Pay configuration form in the OpenCart admin.
		 * It checks for the necessary permissions, validates required fields, and if everything is correct,
		 * saves the provided data using the setting model. It then returns a JSON response indicating success
		 * or any errors encountered.
		 *
		 * @return void
		 */
		public function save(): void 
		{
				$this->load->language('extension/vtbpay/payment/vtbpay');

				$json = [];

				if (!$this->user->hasPermission('modify', 'extension/vtbpay/payment/vtbpay')) {
						$json['error']['warning'] = $this->language->get('error_permission');
				}

				$fields = [
				    'client_id', 
				    'client_secret'
			  ];
			  
				foreach ($fields as $field) {
						if (empty($this->request->post['payment_vtbpay_' . $field])) {
								$json['error'][$field] = $this->language->get('error_' . $field);
						}
				}

				if (!$json) {
						$this->load->model('setting/setting');
						$this->model_setting_setting->editSetting('payment_vtbpay', $this->request->post);
						$json['success'] = $this->language->get('text_success');
				}

				$this->response->addHeader('Content-Type: application/json');
				$this->response->setOutput(json_encode($json));
		}
}
