<?php
namespace Opencart\Catalog\Model\Extension\Vtbpay\Payment;

class Vtbpay extends \Opencart\System\Engine\Model {
	
		/**
		 * Retrieves the payment methods available for VTB Pay.
		 *
		 * This method is responsible for returning the payment methods that are applicable for VTB Pay. It does so by first loading the necessary language
		 * pack for the VTB Pay extension. Next, it fetches the total amount currently present in the user's cart.
		 *
		 * Based on the total amount, if it's greater than or equal to 0.00, the method considers VTB Pay as an available payment method, setting the
		 * status variable to true. If the total amount is less than 0.00, it sets the status variable to false, indicating that VTB Pay is not available as a
		 * payment option.
		 *
		 * If the status is true, the method then creates an array with 'vtbpay' as the key, and the corresponding code and name as its value. It also populates
		 * the method_data array with details such as the code, title, name, option, and sort order for the VTB Pay method.
		 *
		 * Ultimately, the function returns the method_data array which contains the details of the VTB Pay payment method if it's available, otherwise an empty array.
		 *
		 * @param array $address (optional) An array containing address data. This parameter is currently not used in the method. Defaults to an empty array.
		 * @return array An array containing the details of the available VTB Pay payment method. If VTB Pay is not available, an empty array is returned.
		 */
		public function getMethods(array $address = []): array {
			
				$this->load->language('extension/vtbpay/payment/vtbpay');

				$status = false;
				
				$total = $this->cart->getTotal();
				if ((float)$total >= 0.00) {
						$status = true;
				}

				$method_data = [];

				if ($status) {
						$option_data['vtbpay'] = [
								'code' => 'vtbpay.vtbpay',
								'name' => $this->language->get('heading_title')
						];

						$method_data = [
								'code'       => 'vtbpay',
								'title'      => $this->language->get('heading_title'),
								'name'       => $this->language->get('heading_title'),
								'option'     => $option_data,
								'sort_order' => $this->config->get('payment_vtbpay_sort_order'),
						];
				}

				return $method_data;
		}
}